==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/de/help.php <==
<?php

return array(

    /*
    |--------------------------------------------------------------------------
    | Password Reminder Language Lines
    |--------------------------------------------------------------------------
    |
    | The following language lines are the default lines which match reasons
    | that are given by the password broker for a password update attempt
    | has failed, such as for an invalid token or invalid new password.
    |
    */

    "more_info_title" => "Mehr Informationen",

    "audit_help" => "Mit dem aktivieren dieser Option wird der Asset-Datensatz an diesen neuen Ort angepasst. Wenn diese Option nicht aktiviert wird, wird nur der Ort im Audit-Log angezeigt.<br><br>Falls das Asset ausgecheckt ist, ändert sich nicht die Position der Person, des Assets oder der Position, an der es ausgecheckt wird.",

    'assets' => 'Assets sind Elemente, die mit Seriennummer oder einem Asset-Tag versehen sind. Sie sind meist höhere Werte, bei denen die Identifizierung eines bestimmten Gegenstands von Bedeutung ist.',

    'categories' => 'Kategorien helfen Ihnen beim Organisieren von Assets. Beispielkategorien sind &quot;Pcs&quot;, &quot;Laptops&quot;, &quot;Mobiltelefone&quot;, &quot;Tablets&quot; usw., jedoch können Sie Kategorien nutzen, wie Sie es für sinnvoll erachten.',

    'accessories' => 'Zubehör ist alles, was Sie an einen Benutzer ausgeben können, dass jedoch keine Seriennummer besitzt (oder es keinen Sinn macht diese zu verwalten). Zum Beispiel: Mäuse und Tastaturen.',

    'companies'     => 'Unternehmen können als einfaches Identifikationsfeld oder zur Begrenzung der Sichtbarkeit von Assets, Benutzer usw. verwendet werden, wenn die volle Unterstützung für Unternehmen in Ihren Admin-Einstellungen aktiviert ist.',

    'components'    => 'Komponenten sind Teile eines Assets, zum Beispiel eine Festplatte, Arbeitsspeicher, etc.',

    'consumables'   => 'Verbrauchsmaterialien sind alle gekauften Dinge, die mit der Zeit aufgebraucht werden. Zum Beispiel Druckerpatronen oder Kopierpapier.',

    'depreciations' => 'Sie können Asset-Abschreibungen einrichten, um Assets linear abzuschreiben.',



);

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/de/help.php <==
<?php

return [

    /*
    |--------------------------------------------------------------------------
    | Password Reminder Language Lines
    |--------------------------------------------------------------------------
    |
    | The following language lines are the default lines which match reasons
    | that are given by the password broker for a password update attempt
    | has failed, such as for an invalid token or invalid new password.
    |
    */

    'more_info_title' => 'Mehr Informationen',

    'audit_help' => 'Mit dem aktivieren dieser Option wird der Asset-Datensatz an diesen neuen Ort angepasst. Wenn diese Option nicht aktiviert wird, wird nur der Ort im Audit-Log angezeigt.<br><br>Falls das Asset ausgecheckt ist, ändert sich nicht die Position der Person, des Assets oder der Position, an der es ausgecheckt wird.',

    'assets' => 'Assets sind Elemente, die mit Seriennummer oder einem Asset-Tag versehen sind. Sie sind meist höhere Werte, bei denen die Identifizierung eines bestimmten Gegenstands von Bedeutung ist.',

    'categories' => 'Kategorien helfen Ihnen beim Organisieren von Assets. Beispielkategorien sind &quot;Pcs&quot;, &quot;Laptops&quot;, &quot;Mobiltelefone&quot;, &quot;Tablets&quot; usw., jedoch können Sie Kategorien nutzen, wie Sie es für sinnvoll erachten.',

    'accessories' => 'Zubehör ist alles, was Sie an einen Benutzer ausgeben können, dass jedoch keine Seriennummer besitzt (oder es keinen Sinn macht diese zu verwalten). Zum Beispiel: Mäuse und Tastaturen.',

    'companies'     => 'Unternehmen können als einfaches Identifikationsfeld oder zur Begrenzung der Sichtbarkeit von Assets, Benutzer usw. verwendet werden, wenn die volle Unterstützung für Unternehmen in Ihren Admin-Einstellungen aktiviert ist.',

    'components'    => 'Komponenten sind Teile eines Assets, zum Beispiel eine Festplatte, Arbeitsspeicher, etc.',

    'consumables'   => 'Verbrauchsmaterialien sind alle gekauften Dinge, die mit der Zeit aufgebraucht werden. Zum Beispiel Druckerpatronen oder Kopierpapier.',

    'depreciations' => 'Sie können Asset-Abschreibungen einrichten, um Assets linear abzuschreiben.',

];
